@@ -4,6 +4,12 @@ use strict;
 use warnings;
 no warnings 'uninitialized';
 
+use overload
+    '""' => sub { "YID:".shift->{ID} },
+    eq   => sub { shift->{ID} == shift->{ID} },
+    '==' => sub { shift->{ID} == shift->{ID} },
+    fallback => 1;
+
 #
 # This is base class for all Yote objects.
 #
