@@ -253,13 +253,14 @@ sub paginate {
     if( $args->{ return_hash } ) {
         return {} unless $obj_id;
         my $res = $DATASTORE->paginate( $obj_id, $args );
-        return { map { $_ => xform_out( $res->{$_} ) } keys %$res };
+        return { map { $_ => xform_out( $res->{$_} ) } sort keys %$res };
     }
     return [] unless $obj_id;
     return [ map { xform_out( $_ ) } @{ $DATASTORE->paginate( $obj_id, $args ) } ];
 } #paginate
 
 sub recycle_objects {
+    Yote::ObjProvider::stow_all();
     return $DATASTORE->recycle_objects( @_ );
 } #recycle_objects
 
@@ -291,7 +292,7 @@ sub stow {
             __clean( $id );
         }
         for my $child (@$data) {
-            if( $child > 0 && $Yote::ObjProvider::DIRTY->{$child} ) {
+            if( $child =~ /^[0-9]/ && $Yote::ObjProvider::DIRTY->{$child} ) {
                 stow( $Yote::ObjProvider::DIRTY->{$child} );
             }
         }
@@ -302,7 +303,7 @@ sub stow {
         }
         __clean( $id );
         for my $child (values %$data) {
-            if( $child > 0 && $Yote::ObjProvider::DIRTY->{$child} ) {
+            if( $child =~ /^[0-9]/ && $Yote::ObjProvider::DIRTY->{$child} ) {
                 stow( $Yote::ObjProvider::DIRTY->{$child} );
             }
         }
@@ -313,7 +314,7 @@ sub stow {
             __clean( $id );
         }
         for my $val (values %$data) {
-            if( $val > 0 && $Yote::ObjProvider::DIRTY->{$val} ) {
+            if( $val =~ /^[0-9]/ && $Yote::ObjProvider::DIRTY->{$val} ) {
                 stow( $Yote::ObjProvider::DIRTY->{$val} );
             }
         }
